%global momorel 4

%global _exec_prefix %{nil}
%global _libdir %{_exec_prefix}/%{_lib}

Summary: Enhanced system logging and kernel message trapping daemons
Name: rsyslog
Version: 4.6.2
Release: %{momorel}m%{?dist}
License: GPLv3+
Group: System Environment/Daemons
URL: http://www.rsyslog.com/
Source0: http://download.rsyslog.com/rsyslog/%{name}-%{version}.tar.gz
NoSource: 0
Source1: rsyslog.init
Source2: rsyslog.conf
Source3: rsyslog.sysconfig
Source4: rsyslog.log
Patch0: rsyslog-4.6.2-unlimited-select.patch
Patch1: rsyslog-4.6.2-omfileflush.patch
# CVE-2011-3200
Patch2: rsyslog-4.6.3-bz727644.patch
BuildRequires: zlib-devel
BuildRequires: autoconf automake
BuildRequires: openssl-devel >= 1.0.0
Requires: logrotate >= 3.5.2
Requires: bash >= 2.0
Requires(post): chkconfig coreutils
Requires(preun): chkconfig initscripts
Requires(postun): initscripts
Provides: syslog
Provides: sysklogd
Obsoletes: sysklogd
BuildRoot: %{_tmppath}/%{name}-%{version}-%{release}-root-%(%{__id_u} -n)


%package mysql
Summary: MySQL support for rsyslog
Group: System Environment/Daemons
Requires: %{name} = %{version}-%{release}
BuildRequires: mysql-devel >= 5.1.32

%package pgsql
Summary: PostgresSQL support for rsyslog
Group: System Environment/Daemons
Requires: %{name} = %{version}-%{release}
BuildRequires: postgresql-devel

%package gssapi
Summary: GSSAPI authentication and encryption support for rsyslog
Group: System Environment/Daemons
Requires: %{name} = %{version}-%{release}
BuildRequires: krb5-devel 

%package relp
Summary: RELP protocol support for rsyslog
Group: System Environment/Daemons
Requires: %{name} = %{version}-%{release}
BuildRequires: librelp-devel 

%package gnutls
Summary: TLS protocol support for rsyslog
Group: System Environment/Daemons
Requires: %{name} = %{version}-%{release}
BuildRequires: gnutls-devel

%description
Rsyslog is an enhanced multi-threaded syslogd supporting, among others, MySQL,
syslog/tcp, RFC 3195, permitted sender lists, filtering on any message part,
and fine grain output format control. It is quite compatible to stock sysklogd
and can be used as a drop-in replacement. Its advanced features make it 
suitable for enterprise-class, encryption protected syslog relay chains while 
at the same time being very easy to setup for the novice user.

%description mysql
The rsyslog-mysql package contains a dynamic shared object that will add
MySQL database support to rsyslog.

%description pgsql
The rsyslog-pgsql package contains a dynamic shared object that will add
PostgreSQL database support to rsyslog.

%description gssapi
The rsyslog-gssapi package contains the rsyslog plugins which support GSSAPI 
authentication and secure connections. GSSAPI is commonly used for Kerberos 
authentication.

%description relp
The rsyslog-relp package contains the rsyslog plugins that provide
the ability to receive syslog messages via the reliable RELP
protocol. 

%description gnutls
The rsyslog-gnutls package contains the rsyslog plugins that provide the
ability to receive syslog messages via upcoming syslog-transport-tls
IETF standard protocol.

%prep
%setup -q
%patch0 -p1 -b .unlimited-select
%patch1 -p1 -b .omfileflush
%patch2 -p1 -b .bz727644

%build
export CFLAGS="$RPM_OPT_FLAGS -DSYSLOGD_PIDNAME=\\\"syslogd.pid\\\""
# we have to modify LDFLAGS because
# our postgresql-devel-8.4.4-1m still has a problem in ImplicitDSOLinking
export LDFLAGS=`pg_config --ldflags`
%configure	--disable-static \
		--enable-mysql \
		--enable-pgsql \
		--enable-gssapi-krb5 \
		--enable-imfile \
		--enable-relp \
		--enable-gnutls \
		--enable-unlimited-select

make %{?_smp_mflags}

%install
rm -rf %{buildroot}
make install DESTDIR=%{buildroot}

install -d -m 755 %{buildroot}%{_initscriptdir}
install -d -m 755 %{buildroot}%{_sysconfdir}/sysconfig
install -d -m 755 %{buildroot}%{_sysconfdir}/logrotate.d
install -p -m 755 %{SOURCE1} %{buildroot}%{_initscriptdir}/rsyslog
install -p -m 644 %{SOURCE2} %{buildroot}%{_sysconfdir}/rsyslog.conf
install -p -m 644 %{SOURCE3} %{buildroot}%{_sysconfdir}/sysconfig/rsyslog
install -p -m 644 %{SOURCE4} %{buildroot}%{_sysconfdir}/logrotate.d/syslog

#get rid of *.la
rm %{buildroot}/%{_libdir}/rsyslog/*.la

%clean
rm -rf %{buildroot}

%post
/sbin/chkconfig --add rsyslog
for n in /var/log/{messages,secure,maillog,spooler}
do
	[ -f $n ] && continue
	umask 066 && touch $n
done

%preun
if [ $1 = 0 ]; then
	service rsyslog stop >/dev/null 2>&1 ||:
	/sbin/chkconfig --del rsyslog
fi

%postun
if [ "$1" -ge "1" ]; then
	service rsyslog condrestart > /dev/null 2>&1 ||:
fi

%triggerun -- rsyslog < 3.0.0
/bin/kill `cat /var/run/rklogd.pid 2> /dev/null` > /dev/null 2>&1 ||:

%files
%defattr(-,root,root,-)
%doc AUTHORS COPYING NEWS README doc/*html
%dir %{_libdir}/rsyslog
%{_libdir}/rsyslog/imklog.so
%{_libdir}/rsyslog/immark.so
%{_libdir}/rsyslog/imtcp.so
%{_libdir}/rsyslog/imudp.so
%{_libdir}/rsyslog/imuxsock.so
%{_libdir}/rsyslog/imfile.so
%{_libdir}/rsyslog/omtesting.so
%{_libdir}/rsyslog/lmnet.so
%{_libdir}/rsyslog/lmregexp.so
%{_libdir}/rsyslog/lmtcpclt.so
%{_libdir}/rsyslog/lmtcpsrv.so
%{_libdir}/rsyslog/lmnetstrms.so
%{_libdir}/rsyslog/lmnsd_ptcp.so
%{_libdir}/rsyslog/lmstrmsrv.so
%{_libdir}/rsyslog/lmzlibw.so
%config(noreplace) %{_sysconfdir}/rsyslog.conf
%config(noreplace) %{_sysconfdir}/sysconfig/rsyslog
%config(noreplace) %{_sysconfdir}/logrotate.d/syslog
%{_initscriptdir}/rsyslog
%{_sbindir}/rsyslogd
%{_mandir}/*/*

%files mysql
%defattr(-,root,root)
%doc plugins/ommysql/createDB.sql
%{_libdir}/rsyslog/ommysql.so

%files pgsql
%defattr(-,root,root)
%doc plugins/ompgsql/createDB.sql
%{_libdir}/rsyslog/ompgsql.so

%files gssapi
%defattr(-,root,root)
%{_libdir}/rsyslog/lmgssutil.so
%{_libdir}/rsyslog/imgssapi.so
%{_libdir}/rsyslog/omgssapi.so

%files relp
%defattr(-,root,root)
%{_libdir}/rsyslog/imrelp.so
%{_libdir}/rsyslog/omrelp.so

%files gnutls
%defattr(-,root,root)
%{_libdir}/rsyslog/lmnsd_gtls.so

%changelog
* Wed Sep 21 2010 Yohsuke Ooi <meke@momonga-linux.org>
- (4.6.2-4m)
- [SECURITY] CVE-2011-3200

* Tue Aug 31 2010 Yohsuke Ooi <meke@momonga-linux.org>
- (4.6.2-3m)
- full rebuild for mo7 release

* Sat May 22 2010 Hiromasa YOSHIMOTO <y@momonga-linux.org>
- (4.6.2-2m) 
- fix build failure caused by implicit DSO linking issue

* Tue May  4 2010 Yohsuke Ooi <meke@momonga-linux.org>
- (4.6.2-1m)
- update 4.6.2

* Sun Apr  4 2010 NAKAYA Toshiharu <nakaya@momonga-linux.org>
- (3.21.11-3m)
- rebuild against openssl-1.0.0

* Sat Nov 14 2009 NAKAYA Toshiharu <nakaya@momonga-linux.org>
- (3.21.11-2m)
- rebuild against gcc-4.4 and glibc-2.11

* Thu Jun  4 2009 NAKAYA Toshiharu <nakaya@momonga-linux.org>
- (3.21.11-1m)
- update to 3.21.11

* Tue Apr 07 2009 NAKAYA Toshiharu <nakaya@momonga-linux.org>
- (3.21.10-3m)
- rebuild against openssl-0.9.8k

* Thu Mar 19 2009 NAKAYA Toshiharu <nakaya@momonga-linux.org>
- (3.21.10-2m)
- rebuild against mysql-5.1.32

* Thu Feb 12 2009 TABUCHI Takaaki <tab@momonga-linux.org>
- (3.21.10-1m)
- update to 3.21.10

* Wed Jan 21 2009 NAKAYA Toshiharu <nakaya@momonga-linux.org>
- (3.21.9-2m)
- rebuild against rpm-4.6

* Wed Dec 31 2008 NAKAYA Toshiharu <nakaya@momonga-linux.org>
- (3.21.9-1m)
- [SECURITY] CVE-2008-5618
- update to 3.21.9

* Fri Dec  5 2008 TABUCHI Takaaki <tab@momonga-linux.org>
- (3.21.3-1m)
- [SECURITY] CVE-2008-5617
- [SECURITY] RSyslog "AllowedSender" Security Bypass Vulnerability
- - http://secunia.com/Advisories/32857/
- update 3.21.3
- sync with fedora 3.21.3-4

* Mon Aug 25 2008 Yohsuke Ooi <meke@momonga-linux.org> 
- (3.18.1-1m)
- update 3.18.1

* Sun Jul 27 2008 Yohsuke Ooi <meke@momonga-linux.org> 
- (3.16.1-1m)
- update 3.16.1

* Thu Jun  5 2008 NARITA Koichi <pulsar@momonga-linux.org>
- (3.14.1-2m)
- rebuild against openssl-0.9.8h-1m

* Sun May 18 2008 Ichiro Nakai <ichiro@n.email.ne.jp>
- (3.14.1-1m)
- version 3.14.1
- fix up starting order of services at boot up a system
- do the following 3 commands after installing this package
- sudo /sbin/chkconfig messagebus resetpriorities
- sudo /sbin/chkconfig haldaemon resetpriorities
- sudo /sbin/chkconfig NetworkManager resetpriorities
- boot up sequence is all clear now

* Thu Apr 03 2008 TABUCHI Takaaki <tab@momonga-linux.org>
- (1.19.11-4m)
- rebuild against gcc43

* Thu Mar  6 2008 Ichiro Nakai <ichiro@n.email.ne.jp>
- (1.19.11-3m)
- modify Provides and Obsoletes

* Wed Dec 19 2007 Ichiro Nakai <ichiro@n.email.ne.jp>
- (1.19.11-2m)
- modify Requires

* Sat Dec  8 2007 TABUCHI Takaaki <tab@momonga-linux.org>
- (1.19.11-1m)
- update

* Thu Nov  8 2007 TABUCHI Takaaki <tab@momonga-linux.org>
- (1.19.6-1m)
- imoort from Fedora-devel to Momonga

* Wed Oct 03 2007 Peter Vrabec <pvrabec@redhat.com> 1.19.6-3
- remove NUL character from recieved messages

* Tue Sep 25 2007 Tomas Heinrich <theinric@redhat.com> 1.19.6-2
- fix message suppression (303341)

* Tue Sep 25 2007 Tomas Heinrich <theinric@redhat.com> 1.19.6-1
- upstream bugfix release

* Tue Aug 28 2007 Peter Vrabec <pvrabec@redhat.com> 1.19.2-1
- upstream bugfix release
- support for negative app selector, patch from 
  theinric@redhat.com

* Fri Aug 17 2007 Peter Vrabec <pvrabec@redhat.com> 1.19.0-1
- new upstream release with MySQL support(as plugin)

* Wed Aug 08 2007 Peter Vrabec <pvrabec@redhat.com> 1.18.1-1
- upstream bugfix release

* Mon Aug 06 2007 Peter Vrabec <pvrabec@redhat.com> 1.18.0-1
- new upstream release

* Thu Aug 02 2007 Peter Vrabec <pvrabec@redhat.com> 1.17.6-1
- upstream bugfix release

* Mon Jul 30 2007 Peter Vrabec <pvrabec@redhat.com> 1.17.5-1
- upstream bugfix release
- fix typo in provides 

* Wed Jul 25 2007 Jeremy Katz <katzj@redhat.com> - 1.17.2-4
- rebuild for toolchain bug

* Tue Jul 24 2007 Peter Vrabec <pvrabec@redhat.com> 1.17.2-3
- take care of sysklogd configuration files in %%post

* Tue Jul 24 2007 Peter Vrabec <pvrabec@redhat.com> 1.17.2-2
- use EVR in provides/obsoletes sysklogd

* Mon Jul 23 2007 Peter Vrabec <pvrabec@redhat.com> 1.17.2-1
- upstream bug fix release

* Fri Jul 20 2007 Peter Vrabec <pvrabec@redhat.com> 1.17.1-1
- upstream bug fix release
- include html docs (#248712)
- make "-r" option compatible with sysklogd config (248982)

* Tue Jul 17 2007 Peter Vrabec <pvrabec@redhat.com> 1.17.0-1
- feature rich upstream release

* Thu Jul 12 2007 Peter Vrabec <pvrabec@redhat.com> 1.15.1-2
- use obsoletes and hadle old config files

* Wed Jul 11 2007 Peter Vrabec <pvrabec@redhat.com> 1.15.1-1
- new upstream bugfix release

* Tue Jul 10 2007 Peter Vrabec <pvrabec@redhat.com> 1.15.0-1
- new upstream release introduce capability to generate output 
  file names based on templates

* Tue Jul 03 2007 Peter Vrabec <pvrabec@redhat.com> 1.14.2-1
- new upstream bugfix release

* Mon Jul 02 2007 Peter Vrabec <pvrabec@redhat.com> 1.14.1-1
- new upstream release with IPv6 support

* Tue Jun 26 2007 Peter Vrabec <pvrabec@redhat.com> 1.13.5-3
- add BuildRequires for  zlib compression feature

* Mon Jun 25 2007 Peter Vrabec <pvrabec@redhat.com> 1.13.5-2
- some spec file adjustments.
- fix syslog init script error codes (#245330)

* Fri Jun 22 2007 Peter Vrabec <pvrabec@redhat.com> 1.13.5-1
- new upstream release

* Fri Jun 22 2007 Peter Vrabec <pvrabec@redhat.com> 1.13.4-2
- some spec file adjustments.

* Mon Jun 18 2007 Peter Vrabec <pvrabec@redhat.com> 1.13.4-1
- upgrade to new upstream release

* Wed Jun 13 2007 Peter Vrabec <pvrabec@redhat.com> 1.13.2-2
- DB support off

* Tue Jun 12 2007 Peter Vrabec <pvrabec@redhat.com> 1.13.2-1
- new upstream release based on redhat patch

* Fri Jun 08 2007 Peter Vrabec <pvrabec@redhat.com> 1.13.1-2
- rsyslog package provides its own kernel log. daemon (rklogd)

* Mon Jun 04 2007 Peter Vrabec <pvrabec@redhat.com> 1.13.1-1
- Initial rpm build
